"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class OsConfigOsPolicyAssignmentXInstanceFilterXExclusionLabels(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    LABELS_FIELD_NUMBER: builtins.int
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["labels", b"labels"]) -> None: ...

global___OsConfigOsPolicyAssignmentXInstanceFilterXExclusionLabels = OsConfigOsPolicyAssignmentXInstanceFilterXExclusionLabels

@typing_extensions.final
class OsConfigOsPolicyAssignmentXInstanceFilterXInclusionLabels(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    LABELS_FIELD_NUMBER: builtins.int
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["labels", b"labels"]) -> None: ...

global___OsConfigOsPolicyAssignmentXInstanceFilterXInclusionLabels = OsConfigOsPolicyAssignmentXInstanceFilterXInclusionLabels

@typing_extensions.final
class OsConfigOsPolicyAssignmentXInstanceFilterXInventories(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OS_SHORT_NAME_FIELD_NUMBER: builtins.int
    OS_VERSION_FIELD_NUMBER: builtins.int
    os_short_name: builtins.str
    os_version: builtins.str
    def __init__(
        self,
        *,
        os_short_name: builtins.str = ...,
        os_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["os_short_name", b"os_short_name", "os_version", b"os_version"]) -> None: ...

global___OsConfigOsPolicyAssignmentXInstanceFilterXInventories = OsConfigOsPolicyAssignmentXInstanceFilterXInventories

@typing_extensions.final
class OsConfigOsPolicyAssignmentXInstanceFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALL_FIELD_NUMBER: builtins.int
    EXCLUSION_LABELS_FIELD_NUMBER: builtins.int
    INCLUSION_LABELS_FIELD_NUMBER: builtins.int
    INVENTORIES_FIELD_NUMBER: builtins.int
    all: builtins.bool
    @property
    def exclusion_labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OsConfigOsPolicyAssignmentXInstanceFilterXExclusionLabels]: ...
    @property
    def inclusion_labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OsConfigOsPolicyAssignmentXInstanceFilterXInclusionLabels]: ...
    @property
    def inventories(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OsConfigOsPolicyAssignmentXInstanceFilterXInventories]: ...
    def __init__(
        self,
        *,
        all: builtins.bool = ...,
        exclusion_labels: collections.abc.Iterable[global___OsConfigOsPolicyAssignmentXInstanceFilterXExclusionLabels] | None = ...,
        inclusion_labels: collections.abc.Iterable[global___OsConfigOsPolicyAssignmentXInstanceFilterXInclusionLabels] | None = ...,
        inventories: collections.abc.Iterable[global___OsConfigOsPolicyAssignmentXInstanceFilterXInventories] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["all", b"all", "exclusion_labels", b"exclusion_labels", "inclusion_labels", b"inclusion_labels", "inventories", b"inventories"]) -> None: ...

global___OsConfigOsPolicyAssignmentXInstanceFilter = OsConfigOsPolicyAssignmentXInstanceFilter

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXInventoryFilters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OS_SHORT_NAME_FIELD_NUMBER: builtins.int
    OS_VERSION_FIELD_NUMBER: builtins.int
    os_short_name: builtins.str
    os_version: builtins.str
    def __init__(
        self,
        *,
        os_short_name: builtins.str = ...,
        os_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["os_short_name", b"os_short_name", "os_version", b"os_version"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXInventoryFilters = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXInventoryFilters

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFileXGcs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    GENERATION_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    generation: builtins.float
    object: builtins.str
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        generation: builtins.float = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "generation", b"generation", "object", b"object"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFileXGcs = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFileXGcs

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFileXRemote(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHA256_CHECKSUM_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    sha256_checksum: builtins.str
    uri: builtins.str
    def __init__(
        self,
        *,
        sha256_checksum: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sha256_checksum", b"sha256_checksum", "uri", b"uri"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFileXRemote = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFileXRemote

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_INSECURE_FIELD_NUMBER: builtins.int
    LOCAL_PATH_FIELD_NUMBER: builtins.int
    GCS_FIELD_NUMBER: builtins.int
    REMOTE_FIELD_NUMBER: builtins.int
    allow_insecure: builtins.bool
    local_path: builtins.str
    @property
    def gcs(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFileXGcs: ...
    @property
    def remote(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFileXRemote: ...
    def __init__(
        self,
        *,
        allow_insecure: builtins.bool = ...,
        local_path: builtins.str = ...,
        gcs: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFileXGcs | None = ...,
        remote: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFileXRemote | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gcs", b"gcs", "remote", b"remote"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_insecure", b"allow_insecure", "gcs", b"gcs", "local_path", b"local_path", "remote", b"remote"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFile = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFile

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforce(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARGS_FIELD_NUMBER: builtins.int
    INTERPRETER_FIELD_NUMBER: builtins.int
    OUTPUT_FILE_PATH_FIELD_NUMBER: builtins.int
    SCRIPT_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    interpreter: builtins.str
    output_file_path: builtins.str
    script: builtins.str
    @property
    def file(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFile: ...
    def __init__(
        self,
        *,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        interpreter: builtins.str = ...,
        output_file_path: builtins.str = ...,
        script: builtins.str = ...,
        file: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["file", b"file"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["args", b"args", "file", b"file", "interpreter", b"interpreter", "output_file_path", b"output_file_path", "script", b"script"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforce = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforce

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFileXGcs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    GENERATION_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    generation: builtins.float
    object: builtins.str
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        generation: builtins.float = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "generation", b"generation", "object", b"object"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFileXGcs = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFileXGcs

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFileXRemote(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHA256_CHECKSUM_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    sha256_checksum: builtins.str
    uri: builtins.str
    def __init__(
        self,
        *,
        sha256_checksum: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sha256_checksum", b"sha256_checksum", "uri", b"uri"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFileXRemote = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFileXRemote

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_INSECURE_FIELD_NUMBER: builtins.int
    LOCAL_PATH_FIELD_NUMBER: builtins.int
    GCS_FIELD_NUMBER: builtins.int
    REMOTE_FIELD_NUMBER: builtins.int
    allow_insecure: builtins.bool
    local_path: builtins.str
    @property
    def gcs(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFileXGcs: ...
    @property
    def remote(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFileXRemote: ...
    def __init__(
        self,
        *,
        allow_insecure: builtins.bool = ...,
        local_path: builtins.str = ...,
        gcs: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFileXGcs | None = ...,
        remote: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFileXRemote | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gcs", b"gcs", "remote", b"remote"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_insecure", b"allow_insecure", "gcs", b"gcs", "local_path", b"local_path", "remote", b"remote"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFile = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFile

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARGS_FIELD_NUMBER: builtins.int
    INTERPRETER_FIELD_NUMBER: builtins.int
    OUTPUT_FILE_PATH_FIELD_NUMBER: builtins.int
    SCRIPT_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    interpreter: builtins.str
    output_file_path: builtins.str
    script: builtins.str
    @property
    def file(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFile: ...
    def __init__(
        self,
        *,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        interpreter: builtins.str = ...,
        output_file_path: builtins.str = ...,
        script: builtins.str = ...,
        file: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["file", b"file"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["args", b"args", "file", b"file", "interpreter", b"interpreter", "output_file_path", b"output_file_path", "script", b"script"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidate = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidate

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENFORCE_FIELD_NUMBER: builtins.int
    VALIDATE_FIELD_NUMBER: builtins.int
    @property
    def enforce(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforce: ...
    @property
    def validate(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidate: ...
    def __init__(
        self,
        *,
        enforce: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforce | None = ...,
        validate: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidate | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["enforce", b"enforce", "validate", b"validate"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enforce", b"enforce", "validate", b"validate"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExec = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExec

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFileXGcs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    GENERATION_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    generation: builtins.float
    object: builtins.str
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        generation: builtins.float = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "generation", b"generation", "object", b"object"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFileXGcs = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFileXGcs

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFileXRemote(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHA256_CHECKSUM_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    sha256_checksum: builtins.str
    uri: builtins.str
    def __init__(
        self,
        *,
        sha256_checksum: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sha256_checksum", b"sha256_checksum", "uri", b"uri"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFileXRemote = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFileXRemote

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_INSECURE_FIELD_NUMBER: builtins.int
    LOCAL_PATH_FIELD_NUMBER: builtins.int
    GCS_FIELD_NUMBER: builtins.int
    REMOTE_FIELD_NUMBER: builtins.int
    allow_insecure: builtins.bool
    local_path: builtins.str
    @property
    def gcs(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFileXGcs: ...
    @property
    def remote(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFileXRemote: ...
    def __init__(
        self,
        *,
        allow_insecure: builtins.bool = ...,
        local_path: builtins.str = ...,
        gcs: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFileXGcs | None = ...,
        remote: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFileXRemote | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gcs", b"gcs", "remote", b"remote"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_insecure", b"allow_insecure", "gcs", b"gcs", "local_path", b"local_path", "remote", b"remote"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFile = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFile

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    content: builtins.str
    path: builtins.str
    permissions: builtins.str
    state: builtins.str
    @property
    def file(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFile: ...
    def __init__(
        self,
        *,
        content: builtins.str = ...,
        path: builtins.str = ...,
        permissions: builtins.str = ...,
        state: builtins.str = ...,
        file: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["file", b"file"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "file", b"file", "path", b"path", "permissions", b"permissions", "state", b"state"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFile = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFile

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXApt(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXApt = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXApt

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSourceXGcs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    GENERATION_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    generation: builtins.float
    object: builtins.str
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        generation: builtins.float = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "generation", b"generation", "object", b"object"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSourceXGcs = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSourceXGcs

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSourceXRemote(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHA256_CHECKSUM_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    sha256_checksum: builtins.str
    uri: builtins.str
    def __init__(
        self,
        *,
        sha256_checksum: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sha256_checksum", b"sha256_checksum", "uri", b"uri"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSourceXRemote = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSourceXRemote

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_INSECURE_FIELD_NUMBER: builtins.int
    LOCAL_PATH_FIELD_NUMBER: builtins.int
    GCS_FIELD_NUMBER: builtins.int
    REMOTE_FIELD_NUMBER: builtins.int
    allow_insecure: builtins.bool
    local_path: builtins.str
    @property
    def gcs(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSourceXGcs: ...
    @property
    def remote(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSourceXRemote: ...
    def __init__(
        self,
        *,
        allow_insecure: builtins.bool = ...,
        local_path: builtins.str = ...,
        gcs: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSourceXGcs | None = ...,
        remote: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSourceXRemote | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gcs", b"gcs", "remote", b"remote"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_insecure", b"allow_insecure", "gcs", b"gcs", "local_path", b"local_path", "remote", b"remote"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSource = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSource

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDeb(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PULL_DEPS_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    pull_deps: builtins.bool
    @property
    def source(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSource: ...
    def __init__(
        self,
        *,
        pull_deps: builtins.bool = ...,
        source: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pull_deps", b"pull_deps", "source", b"source"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDeb = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDeb

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXGooget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXGooget = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXGooget

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSourceXGcs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    GENERATION_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    generation: builtins.float
    object: builtins.str
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        generation: builtins.float = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "generation", b"generation", "object", b"object"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSourceXGcs = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSourceXGcs

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSourceXRemote(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHA256_CHECKSUM_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    sha256_checksum: builtins.str
    uri: builtins.str
    def __init__(
        self,
        *,
        sha256_checksum: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sha256_checksum", b"sha256_checksum", "uri", b"uri"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSourceXRemote = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSourceXRemote

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_INSECURE_FIELD_NUMBER: builtins.int
    LOCAL_PATH_FIELD_NUMBER: builtins.int
    GCS_FIELD_NUMBER: builtins.int
    REMOTE_FIELD_NUMBER: builtins.int
    allow_insecure: builtins.bool
    local_path: builtins.str
    @property
    def gcs(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSourceXGcs: ...
    @property
    def remote(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSourceXRemote: ...
    def __init__(
        self,
        *,
        allow_insecure: builtins.bool = ...,
        local_path: builtins.str = ...,
        gcs: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSourceXGcs | None = ...,
        remote: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSourceXRemote | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gcs", b"gcs", "remote", b"remote"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_insecure", b"allow_insecure", "gcs", b"gcs", "local_path", b"local_path", "remote", b"remote"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSource = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSource

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsi(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROPERTIES_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    @property
    def properties(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def source(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSource: ...
    def __init__(
        self,
        *,
        properties: collections.abc.Iterable[builtins.str] | None = ...,
        source: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["properties", b"properties", "source", b"source"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsi = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsi

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSourceXGcs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    GENERATION_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    generation: builtins.float
    object: builtins.str
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        generation: builtins.float = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "generation", b"generation", "object", b"object"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSourceXGcs = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSourceXGcs

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSourceXRemote(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHA256_CHECKSUM_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    sha256_checksum: builtins.str
    uri: builtins.str
    def __init__(
        self,
        *,
        sha256_checksum: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sha256_checksum", b"sha256_checksum", "uri", b"uri"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSourceXRemote = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSourceXRemote

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_INSECURE_FIELD_NUMBER: builtins.int
    LOCAL_PATH_FIELD_NUMBER: builtins.int
    GCS_FIELD_NUMBER: builtins.int
    REMOTE_FIELD_NUMBER: builtins.int
    allow_insecure: builtins.bool
    local_path: builtins.str
    @property
    def gcs(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSourceXGcs: ...
    @property
    def remote(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSourceXRemote: ...
    def __init__(
        self,
        *,
        allow_insecure: builtins.bool = ...,
        local_path: builtins.str = ...,
        gcs: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSourceXGcs | None = ...,
        remote: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSourceXRemote | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gcs", b"gcs", "remote", b"remote"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_insecure", b"allow_insecure", "gcs", b"gcs", "local_path", b"local_path", "remote", b"remote"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSource = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSource

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PULL_DEPS_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    pull_deps: builtins.bool
    @property
    def source(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSource: ...
    def __init__(
        self,
        *,
        pull_deps: builtins.bool = ...,
        source: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pull_deps", b"pull_deps", "source", b"source"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpm = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpm

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXYum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXYum = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXYum

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXZypper(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXZypper = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXZypper

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_FIELD_NUMBER: builtins.int
    APT_FIELD_NUMBER: builtins.int
    DEB_FIELD_NUMBER: builtins.int
    GOOGET_FIELD_NUMBER: builtins.int
    MSI_FIELD_NUMBER: builtins.int
    RPM_FIELD_NUMBER: builtins.int
    YUM_FIELD_NUMBER: builtins.int
    ZYPPER_FIELD_NUMBER: builtins.int
    desired_state: builtins.str
    @property
    def apt(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXApt: ...
    @property
    def deb(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDeb: ...
    @property
    def googet(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXGooget: ...
    @property
    def msi(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsi: ...
    @property
    def rpm(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpm: ...
    @property
    def yum(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXYum: ...
    @property
    def zypper(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXZypper: ...
    def __init__(
        self,
        *,
        desired_state: builtins.str = ...,
        apt: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXApt | None = ...,
        deb: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDeb | None = ...,
        googet: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXGooget | None = ...,
        msi: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsi | None = ...,
        rpm: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpm | None = ...,
        yum: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXYum | None = ...,
        zypper: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXZypper | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["apt", b"apt", "deb", b"deb", "googet", b"googet", "msi", b"msi", "rpm", b"rpm", "yum", b"yum", "zypper", b"zypper"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["apt", b"apt", "deb", b"deb", "desired_state", b"desired_state", "googet", b"googet", "msi", b"msi", "rpm", b"rpm", "yum", b"yum", "zypper", b"zypper"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkg = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkg

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXApt(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARCHIVE_TYPE_FIELD_NUMBER: builtins.int
    COMPONENTS_FIELD_NUMBER: builtins.int
    DISTRIBUTION_FIELD_NUMBER: builtins.int
    GPG_KEY_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    archive_type: builtins.str
    @property
    def components(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    distribution: builtins.str
    gpg_key: builtins.str
    uri: builtins.str
    def __init__(
        self,
        *,
        archive_type: builtins.str = ...,
        components: collections.abc.Iterable[builtins.str] | None = ...,
        distribution: builtins.str = ...,
        gpg_key: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["archive_type", b"archive_type", "components", b"components", "distribution", b"distribution", "gpg_key", b"gpg_key", "uri", b"uri"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXApt = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXApt

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXGoo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    name: builtins.str
    url: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "url", b"url"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXGoo = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXGoo

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXYum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_URL_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    GPG_KEYS_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    base_url: builtins.str
    display_name: builtins.str
    @property
    def gpg_keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    id: builtins.str
    def __init__(
        self,
        *,
        base_url: builtins.str = ...,
        display_name: builtins.str = ...,
        gpg_keys: collections.abc.Iterable[builtins.str] | None = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_url", b"base_url", "display_name", b"display_name", "gpg_keys", b"gpg_keys", "id", b"id"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXYum = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXYum

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXZypper(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_URL_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    GPG_KEYS_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    base_url: builtins.str
    display_name: builtins.str
    @property
    def gpg_keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    id: builtins.str
    def __init__(
        self,
        *,
        base_url: builtins.str = ...,
        display_name: builtins.str = ...,
        gpg_keys: collections.abc.Iterable[builtins.str] | None = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_url", b"base_url", "display_name", b"display_name", "gpg_keys", b"gpg_keys", "id", b"id"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXZypper = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXZypper

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepository(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APT_FIELD_NUMBER: builtins.int
    GOO_FIELD_NUMBER: builtins.int
    YUM_FIELD_NUMBER: builtins.int
    ZYPPER_FIELD_NUMBER: builtins.int
    @property
    def apt(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXApt: ...
    @property
    def goo(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXGoo: ...
    @property
    def yum(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXYum: ...
    @property
    def zypper(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXZypper: ...
    def __init__(
        self,
        *,
        apt: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXApt | None = ...,
        goo: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXGoo | None = ...,
        yum: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXYum | None = ...,
        zypper: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXZypper | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["apt", b"apt", "goo", b"goo", "yum", b"yum", "zypper", b"zypper"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["apt", b"apt", "goo", b"goo", "yum", b"yum", "zypper", b"zypper"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepository = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepository

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    EXEC_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    PKG_FIELD_NUMBER: builtins.int
    REPOSITORY_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def exec(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExec: ...
    @property
    def file(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFile: ...
    @property
    def pkg(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkg: ...
    @property
    def repository(self) -> global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepository: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        exec: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExec | None = ...,
        file: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFile | None = ...,
        pkg: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkg | None = ...,
        repository: global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepository | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["exec", b"exec", "file", b"file", "pkg", b"pkg", "repository", b"repository"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["exec", b"exec", "file", b"file", "id", b"id", "pkg", b"pkg", "repository", b"repository"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResources = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResources

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVENTORY_FILTERS_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    @property
    def inventory_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXInventoryFilters]: ...
    @property
    def resources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResources]: ...
    def __init__(
        self,
        *,
        inventory_filters: collections.abc.Iterable[global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXInventoryFilters] | None = ...,
        resources: collections.abc.Iterable[global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResources] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["inventory_filters", b"inventory_filters", "resources", b"resources"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroups = OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroups

@typing_extensions.final
class OsConfigOsPolicyAssignmentXOsPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_NO_RESOURCE_GROUP_MATCH_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    RESOURCE_GROUPS_FIELD_NUMBER: builtins.int
    allow_no_resource_group_match: builtins.bool
    description: builtins.str
    id: builtins.str
    mode: builtins.str
    @property
    def resource_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroups]: ...
    def __init__(
        self,
        *,
        allow_no_resource_group_match: builtins.bool = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        mode: builtins.str = ...,
        resource_groups: collections.abc.Iterable[global___OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroups] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_no_resource_group_match", b"allow_no_resource_group_match", "description", b"description", "id", b"id", "mode", b"mode", "resource_groups", b"resource_groups"]) -> None: ...

global___OsConfigOsPolicyAssignmentXOsPolicies = OsConfigOsPolicyAssignmentXOsPolicies

@typing_extensions.final
class OsConfigOsPolicyAssignmentXRolloutXDisruptionBudget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIXED_FIELD_NUMBER: builtins.int
    PERCENT_FIELD_NUMBER: builtins.int
    fixed: builtins.float
    percent: builtins.float
    def __init__(
        self,
        *,
        fixed: builtins.float = ...,
        percent: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fixed", b"fixed", "percent", b"percent"]) -> None: ...

global___OsConfigOsPolicyAssignmentXRolloutXDisruptionBudget = OsConfigOsPolicyAssignmentXRolloutXDisruptionBudget

@typing_extensions.final
class OsConfigOsPolicyAssignmentXRollout(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_WAIT_DURATION_FIELD_NUMBER: builtins.int
    DISRUPTION_BUDGET_FIELD_NUMBER: builtins.int
    min_wait_duration: builtins.str
    @property
    def disruption_budget(self) -> global___OsConfigOsPolicyAssignmentXRolloutXDisruptionBudget: ...
    def __init__(
        self,
        *,
        min_wait_duration: builtins.str = ...,
        disruption_budget: global___OsConfigOsPolicyAssignmentXRolloutXDisruptionBudget | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["disruption_budget", b"disruption_budget"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disruption_budget", b"disruption_budget", "min_wait_duration", b"min_wait_duration"]) -> None: ...

global___OsConfigOsPolicyAssignmentXRollout = OsConfigOsPolicyAssignmentXRollout

@typing_extensions.final
class OsConfigOsPolicyAssignmentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___OsConfigOsPolicyAssignmentXTimeouts = OsConfigOsPolicyAssignmentXTimeouts

@typing_extensions.final
class OsConfigOsPolicyAssignment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASELINE_FIELD_NUMBER: builtins.int
    DELETED_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RECONCILING_FIELD_NUMBER: builtins.int
    REVISION_CREATE_TIME_FIELD_NUMBER: builtins.int
    REVISION_ID_FIELD_NUMBER: builtins.int
    ROLLOUT_STATE_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    INSTANCE_FILTER_FIELD_NUMBER: builtins.int
    OS_POLICIES_FIELD_NUMBER: builtins.int
    ROLLOUT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    baseline: builtins.bool
    deleted: builtins.bool
    description: builtins.str
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    name: builtins.str
    project: builtins.str
    reconciling: builtins.bool
    revision_create_time: builtins.str
    revision_id: builtins.str
    rollout_state: builtins.str
    uid: builtins.str
    @property
    def instance_filter(self) -> global___OsConfigOsPolicyAssignmentXInstanceFilter: ...
    @property
    def os_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OsConfigOsPolicyAssignmentXOsPolicies]: ...
    @property
    def rollout(self) -> global___OsConfigOsPolicyAssignmentXRollout: ...
    @property
    def timeouts(self) -> global___OsConfigOsPolicyAssignmentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        baseline: builtins.bool = ...,
        deleted: builtins.bool = ...,
        description: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        reconciling: builtins.bool = ...,
        revision_create_time: builtins.str = ...,
        revision_id: builtins.str = ...,
        rollout_state: builtins.str = ...,
        uid: builtins.str = ...,
        instance_filter: global___OsConfigOsPolicyAssignmentXInstanceFilter | None = ...,
        os_policies: collections.abc.Iterable[global___OsConfigOsPolicyAssignmentXOsPolicies] | None = ...,
        rollout: global___OsConfigOsPolicyAssignmentXRollout | None = ...,
        timeouts: global___OsConfigOsPolicyAssignmentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["instance_filter", b"instance_filter", "resource_info", b"resource_info", "rollout", b"rollout", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["baseline", b"baseline", "deleted", b"deleted", "description", b"description", "etag", b"etag", "id", b"id", "instance_filter", b"instance_filter", "location", b"location", "name", b"name", "os_policies", b"os_policies", "project", b"project", "reconciling", b"reconciling", "resource_info", b"resource_info", "revision_create_time", b"revision_create_time", "revision_id", b"revision_id", "rollout", b"rollout", "rollout_state", b"rollout_state", "timeouts", b"timeouts", "uid", b"uid"]) -> None: ...

global___OsConfigOsPolicyAssignment = OsConfigOsPolicyAssignment

@typing_extensions.final
class OsConfigPatchDeploymentXInstanceFilterXGroupLabels(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    LABELS_FIELD_NUMBER: builtins.int
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["labels", b"labels"]) -> None: ...

global___OsConfigPatchDeploymentXInstanceFilterXGroupLabels = OsConfigPatchDeploymentXInstanceFilterXGroupLabels

@typing_extensions.final
class OsConfigPatchDeploymentXInstanceFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALL_FIELD_NUMBER: builtins.int
    INSTANCE_NAME_PREFIXES_FIELD_NUMBER: builtins.int
    INSTANCES_FIELD_NUMBER: builtins.int
    ZONES_FIELD_NUMBER: builtins.int
    GROUP_LABELS_FIELD_NUMBER: builtins.int
    all: builtins.bool
    @property
    def instance_name_prefixes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def instances(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def zones(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def group_labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OsConfigPatchDeploymentXInstanceFilterXGroupLabels]: ...
    def __init__(
        self,
        *,
        all: builtins.bool = ...,
        instance_name_prefixes: collections.abc.Iterable[builtins.str] | None = ...,
        instances: collections.abc.Iterable[builtins.str] | None = ...,
        zones: collections.abc.Iterable[builtins.str] | None = ...,
        group_labels: collections.abc.Iterable[global___OsConfigPatchDeploymentXInstanceFilterXGroupLabels] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["all", b"all", "group_labels", b"group_labels", "instance_name_prefixes", b"instance_name_prefixes", "instances", b"instances", "zones", b"zones"]) -> None: ...

global___OsConfigPatchDeploymentXInstanceFilter = OsConfigPatchDeploymentXInstanceFilter

@typing_extensions.final
class OsConfigPatchDeploymentXOneTimeSchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTE_TIME_FIELD_NUMBER: builtins.int
    execute_time: builtins.str
    def __init__(
        self,
        *,
        execute_time: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execute_time", b"execute_time"]) -> None: ...

global___OsConfigPatchDeploymentXOneTimeSchedule = OsConfigPatchDeploymentXOneTimeSchedule

@typing_extensions.final
class OsConfigPatchDeploymentXPatchConfigXApt(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXCLUDES_FIELD_NUMBER: builtins.int
    EXCLUSIVE_PACKAGES_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def excludes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def exclusive_packages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    type: builtins.str
    def __init__(
        self,
        *,
        excludes: collections.abc.Iterable[builtins.str] | None = ...,
        exclusive_packages: collections.abc.Iterable[builtins.str] | None = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["excludes", b"excludes", "exclusive_packages", b"exclusive_packages", "type", b"type"]) -> None: ...

global___OsConfigPatchDeploymentXPatchConfigXApt = OsConfigPatchDeploymentXPatchConfigXApt

@typing_extensions.final
class OsConfigPatchDeploymentXPatchConfigXGoo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled"]) -> None: ...

global___OsConfigPatchDeploymentXPatchConfigXGoo = OsConfigPatchDeploymentXPatchConfigXGoo

@typing_extensions.final
class OsConfigPatchDeploymentXPatchConfigXPostStepXLinuxExecStepConfigXGcsObject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    GENERATION_NUMBER_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    generation_number: builtins.str
    object: builtins.str
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        generation_number: builtins.str = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "generation_number", b"generation_number", "object", b"object"]) -> None: ...

global___OsConfigPatchDeploymentXPatchConfigXPostStepXLinuxExecStepConfigXGcsObject = OsConfigPatchDeploymentXPatchConfigXPostStepXLinuxExecStepConfigXGcsObject

@typing_extensions.final
class OsConfigPatchDeploymentXPatchConfigXPostStepXLinuxExecStepConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_SUCCESS_CODES_FIELD_NUMBER: builtins.int
    INTERPRETER_FIELD_NUMBER: builtins.int
    LOCAL_PATH_FIELD_NUMBER: builtins.int
    GCS_OBJECT_FIELD_NUMBER: builtins.int
    @property
    def allowed_success_codes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    interpreter: builtins.str
    local_path: builtins.str
    @property
    def gcs_object(self) -> global___OsConfigPatchDeploymentXPatchConfigXPostStepXLinuxExecStepConfigXGcsObject: ...
    def __init__(
        self,
        *,
        allowed_success_codes: collections.abc.Iterable[builtins.float] | None = ...,
        interpreter: builtins.str = ...,
        local_path: builtins.str = ...,
        gcs_object: global___OsConfigPatchDeploymentXPatchConfigXPostStepXLinuxExecStepConfigXGcsObject | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gcs_object", b"gcs_object"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_success_codes", b"allowed_success_codes", "gcs_object", b"gcs_object", "interpreter", b"interpreter", "local_path", b"local_path"]) -> None: ...

global___OsConfigPatchDeploymentXPatchConfigXPostStepXLinuxExecStepConfig = OsConfigPatchDeploymentXPatchConfigXPostStepXLinuxExecStepConfig

@typing_extensions.final
class OsConfigPatchDeploymentXPatchConfigXPostStepXWindowsExecStepConfigXGcsObject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    GENERATION_NUMBER_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    generation_number: builtins.str
    object: builtins.str
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        generation_number: builtins.str = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "generation_number", b"generation_number", "object", b"object"]) -> None: ...

global___OsConfigPatchDeploymentXPatchConfigXPostStepXWindowsExecStepConfigXGcsObject = OsConfigPatchDeploymentXPatchConfigXPostStepXWindowsExecStepConfigXGcsObject

@typing_extensions.final
class OsConfigPatchDeploymentXPatchConfigXPostStepXWindowsExecStepConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_SUCCESS_CODES_FIELD_NUMBER: builtins.int
    INTERPRETER_FIELD_NUMBER: builtins.int
    LOCAL_PATH_FIELD_NUMBER: builtins.int
    GCS_OBJECT_FIELD_NUMBER: builtins.int
    @property
    def allowed_success_codes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    interpreter: builtins.str
    local_path: builtins.str
    @property
    def gcs_object(self) -> global___OsConfigPatchDeploymentXPatchConfigXPostStepXWindowsExecStepConfigXGcsObject: ...
    def __init__(
        self,
        *,
        allowed_success_codes: collections.abc.Iterable[builtins.float] | None = ...,
        interpreter: builtins.str = ...,
        local_path: builtins.str = ...,
        gcs_object: global___OsConfigPatchDeploymentXPatchConfigXPostStepXWindowsExecStepConfigXGcsObject | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gcs_object", b"gcs_object"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_success_codes", b"allowed_success_codes", "gcs_object", b"gcs_object", "interpreter", b"interpreter", "local_path", b"local_path"]) -> None: ...

global___OsConfigPatchDeploymentXPatchConfigXPostStepXWindowsExecStepConfig = OsConfigPatchDeploymentXPatchConfigXPostStepXWindowsExecStepConfig

@typing_extensions.final
class OsConfigPatchDeploymentXPatchConfigXPostStep(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LINUX_EXEC_STEP_CONFIG_FIELD_NUMBER: builtins.int
    WINDOWS_EXEC_STEP_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def linux_exec_step_config(self) -> global___OsConfigPatchDeploymentXPatchConfigXPostStepXLinuxExecStepConfig: ...
    @property
    def windows_exec_step_config(self) -> global___OsConfigPatchDeploymentXPatchConfigXPostStepXWindowsExecStepConfig: ...
    def __init__(
        self,
        *,
        linux_exec_step_config: global___OsConfigPatchDeploymentXPatchConfigXPostStepXLinuxExecStepConfig | None = ...,
        windows_exec_step_config: global___OsConfigPatchDeploymentXPatchConfigXPostStepXWindowsExecStepConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["linux_exec_step_config", b"linux_exec_step_config", "windows_exec_step_config", b"windows_exec_step_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["linux_exec_step_config", b"linux_exec_step_config", "windows_exec_step_config", b"windows_exec_step_config"]) -> None: ...

global___OsConfigPatchDeploymentXPatchConfigXPostStep = OsConfigPatchDeploymentXPatchConfigXPostStep

@typing_extensions.final
class OsConfigPatchDeploymentXPatchConfigXPreStepXLinuxExecStepConfigXGcsObject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    GENERATION_NUMBER_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    generation_number: builtins.str
    object: builtins.str
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        generation_number: builtins.str = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "generation_number", b"generation_number", "object", b"object"]) -> None: ...

global___OsConfigPatchDeploymentXPatchConfigXPreStepXLinuxExecStepConfigXGcsObject = OsConfigPatchDeploymentXPatchConfigXPreStepXLinuxExecStepConfigXGcsObject

@typing_extensions.final
class OsConfigPatchDeploymentXPatchConfigXPreStepXLinuxExecStepConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_SUCCESS_CODES_FIELD_NUMBER: builtins.int
    INTERPRETER_FIELD_NUMBER: builtins.int
    LOCAL_PATH_FIELD_NUMBER: builtins.int
    GCS_OBJECT_FIELD_NUMBER: builtins.int
    @property
    def allowed_success_codes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    interpreter: builtins.str
    local_path: builtins.str
    @property
    def gcs_object(self) -> global___OsConfigPatchDeploymentXPatchConfigXPreStepXLinuxExecStepConfigXGcsObject: ...
    def __init__(
        self,
        *,
        allowed_success_codes: collections.abc.Iterable[builtins.float] | None = ...,
        interpreter: builtins.str = ...,
        local_path: builtins.str = ...,
        gcs_object: global___OsConfigPatchDeploymentXPatchConfigXPreStepXLinuxExecStepConfigXGcsObject | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gcs_object", b"gcs_object"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_success_codes", b"allowed_success_codes", "gcs_object", b"gcs_object", "interpreter", b"interpreter", "local_path", b"local_path"]) -> None: ...

global___OsConfigPatchDeploymentXPatchConfigXPreStepXLinuxExecStepConfig = OsConfigPatchDeploymentXPatchConfigXPreStepXLinuxExecStepConfig

@typing_extensions.final
class OsConfigPatchDeploymentXPatchConfigXPreStepXWindowsExecStepConfigXGcsObject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    GENERATION_NUMBER_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    generation_number: builtins.str
    object: builtins.str
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        generation_number: builtins.str = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "generation_number", b"generation_number", "object", b"object"]) -> None: ...

global___OsConfigPatchDeploymentXPatchConfigXPreStepXWindowsExecStepConfigXGcsObject = OsConfigPatchDeploymentXPatchConfigXPreStepXWindowsExecStepConfigXGcsObject

@typing_extensions.final
class OsConfigPatchDeploymentXPatchConfigXPreStepXWindowsExecStepConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_SUCCESS_CODES_FIELD_NUMBER: builtins.int
    INTERPRETER_FIELD_NUMBER: builtins.int
    LOCAL_PATH_FIELD_NUMBER: builtins.int
    GCS_OBJECT_FIELD_NUMBER: builtins.int
    @property
    def allowed_success_codes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    interpreter: builtins.str
    local_path: builtins.str
    @property
    def gcs_object(self) -> global___OsConfigPatchDeploymentXPatchConfigXPreStepXWindowsExecStepConfigXGcsObject: ...
    def __init__(
        self,
        *,
        allowed_success_codes: collections.abc.Iterable[builtins.float] | None = ...,
        interpreter: builtins.str = ...,
        local_path: builtins.str = ...,
        gcs_object: global___OsConfigPatchDeploymentXPatchConfigXPreStepXWindowsExecStepConfigXGcsObject | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gcs_object", b"gcs_object"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_success_codes", b"allowed_success_codes", "gcs_object", b"gcs_object", "interpreter", b"interpreter", "local_path", b"local_path"]) -> None: ...

global___OsConfigPatchDeploymentXPatchConfigXPreStepXWindowsExecStepConfig = OsConfigPatchDeploymentXPatchConfigXPreStepXWindowsExecStepConfig

@typing_extensions.final
class OsConfigPatchDeploymentXPatchConfigXPreStep(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LINUX_EXEC_STEP_CONFIG_FIELD_NUMBER: builtins.int
    WINDOWS_EXEC_STEP_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def linux_exec_step_config(self) -> global___OsConfigPatchDeploymentXPatchConfigXPreStepXLinuxExecStepConfig: ...
    @property
    def windows_exec_step_config(self) -> global___OsConfigPatchDeploymentXPatchConfigXPreStepXWindowsExecStepConfig: ...
    def __init__(
        self,
        *,
        linux_exec_step_config: global___OsConfigPatchDeploymentXPatchConfigXPreStepXLinuxExecStepConfig | None = ...,
        windows_exec_step_config: global___OsConfigPatchDeploymentXPatchConfigXPreStepXWindowsExecStepConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["linux_exec_step_config", b"linux_exec_step_config", "windows_exec_step_config", b"windows_exec_step_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["linux_exec_step_config", b"linux_exec_step_config", "windows_exec_step_config", b"windows_exec_step_config"]) -> None: ...

global___OsConfigPatchDeploymentXPatchConfigXPreStep = OsConfigPatchDeploymentXPatchConfigXPreStep

@typing_extensions.final
class OsConfigPatchDeploymentXPatchConfigXWindowsUpdate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLASSIFICATIONS_FIELD_NUMBER: builtins.int
    EXCLUDES_FIELD_NUMBER: builtins.int
    EXCLUSIVE_PATCHES_FIELD_NUMBER: builtins.int
    @property
    def classifications(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def excludes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def exclusive_patches(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        classifications: collections.abc.Iterable[builtins.str] | None = ...,
        excludes: collections.abc.Iterable[builtins.str] | None = ...,
        exclusive_patches: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["classifications", b"classifications", "excludes", b"excludes", "exclusive_patches", b"exclusive_patches"]) -> None: ...

global___OsConfigPatchDeploymentXPatchConfigXWindowsUpdate = OsConfigPatchDeploymentXPatchConfigXWindowsUpdate

@typing_extensions.final
class OsConfigPatchDeploymentXPatchConfigXYum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXCLUDES_FIELD_NUMBER: builtins.int
    EXCLUSIVE_PACKAGES_FIELD_NUMBER: builtins.int
    MINIMAL_FIELD_NUMBER: builtins.int
    SECURITY_FIELD_NUMBER: builtins.int
    @property
    def excludes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def exclusive_packages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    minimal: builtins.bool
    security: builtins.bool
    def __init__(
        self,
        *,
        excludes: collections.abc.Iterable[builtins.str] | None = ...,
        exclusive_packages: collections.abc.Iterable[builtins.str] | None = ...,
        minimal: builtins.bool = ...,
        security: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["excludes", b"excludes", "exclusive_packages", b"exclusive_packages", "minimal", b"minimal", "security", b"security"]) -> None: ...

global___OsConfigPatchDeploymentXPatchConfigXYum = OsConfigPatchDeploymentXPatchConfigXYum

@typing_extensions.final
class OsConfigPatchDeploymentXPatchConfigXZypper(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATEGORIES_FIELD_NUMBER: builtins.int
    EXCLUDES_FIELD_NUMBER: builtins.int
    EXCLUSIVE_PATCHES_FIELD_NUMBER: builtins.int
    SEVERITIES_FIELD_NUMBER: builtins.int
    WITH_OPTIONAL_FIELD_NUMBER: builtins.int
    WITH_UPDATE_FIELD_NUMBER: builtins.int
    @property
    def categories(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def excludes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def exclusive_patches(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def severities(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    with_optional: builtins.bool
    with_update: builtins.bool
    def __init__(
        self,
        *,
        categories: collections.abc.Iterable[builtins.str] | None = ...,
        excludes: collections.abc.Iterable[builtins.str] | None = ...,
        exclusive_patches: collections.abc.Iterable[builtins.str] | None = ...,
        severities: collections.abc.Iterable[builtins.str] | None = ...,
        with_optional: builtins.bool = ...,
        with_update: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["categories", b"categories", "excludes", b"excludes", "exclusive_patches", b"exclusive_patches", "severities", b"severities", "with_optional", b"with_optional", "with_update", b"with_update"]) -> None: ...

global___OsConfigPatchDeploymentXPatchConfigXZypper = OsConfigPatchDeploymentXPatchConfigXZypper

@typing_extensions.final
class OsConfigPatchDeploymentXPatchConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIG_INSTANCES_ALLOWED_FIELD_NUMBER: builtins.int
    REBOOT_CONFIG_FIELD_NUMBER: builtins.int
    APT_FIELD_NUMBER: builtins.int
    GOO_FIELD_NUMBER: builtins.int
    POST_STEP_FIELD_NUMBER: builtins.int
    PRE_STEP_FIELD_NUMBER: builtins.int
    WINDOWS_UPDATE_FIELD_NUMBER: builtins.int
    YUM_FIELD_NUMBER: builtins.int
    ZYPPER_FIELD_NUMBER: builtins.int
    mig_instances_allowed: builtins.bool
    reboot_config: builtins.str
    @property
    def apt(self) -> global___OsConfigPatchDeploymentXPatchConfigXApt: ...
    @property
    def goo(self) -> global___OsConfigPatchDeploymentXPatchConfigXGoo: ...
    @property
    def post_step(self) -> global___OsConfigPatchDeploymentXPatchConfigXPostStep: ...
    @property
    def pre_step(self) -> global___OsConfigPatchDeploymentXPatchConfigXPreStep: ...
    @property
    def windows_update(self) -> global___OsConfigPatchDeploymentXPatchConfigXWindowsUpdate: ...
    @property
    def yum(self) -> global___OsConfigPatchDeploymentXPatchConfigXYum: ...
    @property
    def zypper(self) -> global___OsConfigPatchDeploymentXPatchConfigXZypper: ...
    def __init__(
        self,
        *,
        mig_instances_allowed: builtins.bool = ...,
        reboot_config: builtins.str = ...,
        apt: global___OsConfigPatchDeploymentXPatchConfigXApt | None = ...,
        goo: global___OsConfigPatchDeploymentXPatchConfigXGoo | None = ...,
        post_step: global___OsConfigPatchDeploymentXPatchConfigXPostStep | None = ...,
        pre_step: global___OsConfigPatchDeploymentXPatchConfigXPreStep | None = ...,
        windows_update: global___OsConfigPatchDeploymentXPatchConfigXWindowsUpdate | None = ...,
        yum: global___OsConfigPatchDeploymentXPatchConfigXYum | None = ...,
        zypper: global___OsConfigPatchDeploymentXPatchConfigXZypper | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["apt", b"apt", "goo", b"goo", "post_step", b"post_step", "pre_step", b"pre_step", "windows_update", b"windows_update", "yum", b"yum", "zypper", b"zypper"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["apt", b"apt", "goo", b"goo", "mig_instances_allowed", b"mig_instances_allowed", "post_step", b"post_step", "pre_step", b"pre_step", "reboot_config", b"reboot_config", "windows_update", b"windows_update", "yum", b"yum", "zypper", b"zypper"]) -> None: ...

global___OsConfigPatchDeploymentXPatchConfig = OsConfigPatchDeploymentXPatchConfig

@typing_extensions.final
class OsConfigPatchDeploymentXRecurringScheduleXMonthlyXWeekDayOfMonth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAY_OF_WEEK_FIELD_NUMBER: builtins.int
    WEEK_ORDINAL_FIELD_NUMBER: builtins.int
    day_of_week: builtins.str
    week_ordinal: builtins.float
    def __init__(
        self,
        *,
        day_of_week: builtins.str = ...,
        week_ordinal: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["day_of_week", b"day_of_week", "week_ordinal", b"week_ordinal"]) -> None: ...

global___OsConfigPatchDeploymentXRecurringScheduleXMonthlyXWeekDayOfMonth = OsConfigPatchDeploymentXRecurringScheduleXMonthlyXWeekDayOfMonth

@typing_extensions.final
class OsConfigPatchDeploymentXRecurringScheduleXMonthly(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MONTH_DAY_FIELD_NUMBER: builtins.int
    WEEK_DAY_OF_MONTH_FIELD_NUMBER: builtins.int
    month_day: builtins.float
    @property
    def week_day_of_month(self) -> global___OsConfigPatchDeploymentXRecurringScheduleXMonthlyXWeekDayOfMonth: ...
    def __init__(
        self,
        *,
        month_day: builtins.float = ...,
        week_day_of_month: global___OsConfigPatchDeploymentXRecurringScheduleXMonthlyXWeekDayOfMonth | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["week_day_of_month", b"week_day_of_month"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["month_day", b"month_day", "week_day_of_month", b"week_day_of_month"]) -> None: ...

global___OsConfigPatchDeploymentXRecurringScheduleXMonthly = OsConfigPatchDeploymentXRecurringScheduleXMonthly

@typing_extensions.final
class OsConfigPatchDeploymentXRecurringScheduleXTimeOfDay(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOURS_FIELD_NUMBER: builtins.int
    MINUTES_FIELD_NUMBER: builtins.int
    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    hours: builtins.float
    minutes: builtins.float
    nanos: builtins.float
    seconds: builtins.float
    def __init__(
        self,
        *,
        hours: builtins.float = ...,
        minutes: builtins.float = ...,
        nanos: builtins.float = ...,
        seconds: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hours", b"hours", "minutes", b"minutes", "nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___OsConfigPatchDeploymentXRecurringScheduleXTimeOfDay = OsConfigPatchDeploymentXRecurringScheduleXTimeOfDay

@typing_extensions.final
class OsConfigPatchDeploymentXRecurringScheduleXTimeZone(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    id: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "version", b"version"]) -> None: ...

global___OsConfigPatchDeploymentXRecurringScheduleXTimeZone = OsConfigPatchDeploymentXRecurringScheduleXTimeZone

@typing_extensions.final
class OsConfigPatchDeploymentXRecurringScheduleXWeekly(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAY_OF_WEEK_FIELD_NUMBER: builtins.int
    day_of_week: builtins.str
    def __init__(
        self,
        *,
        day_of_week: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["day_of_week", b"day_of_week"]) -> None: ...

global___OsConfigPatchDeploymentXRecurringScheduleXWeekly = OsConfigPatchDeploymentXRecurringScheduleXWeekly

@typing_extensions.final
class OsConfigPatchDeploymentXRecurringSchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    END_TIME_FIELD_NUMBER: builtins.int
    LAST_EXECUTE_TIME_FIELD_NUMBER: builtins.int
    NEXT_EXECUTE_TIME_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    MONTHLY_FIELD_NUMBER: builtins.int
    TIME_OF_DAY_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    WEEKLY_FIELD_NUMBER: builtins.int
    end_time: builtins.str
    last_execute_time: builtins.str
    next_execute_time: builtins.str
    start_time: builtins.str
    @property
    def monthly(self) -> global___OsConfigPatchDeploymentXRecurringScheduleXMonthly: ...
    @property
    def time_of_day(self) -> global___OsConfigPatchDeploymentXRecurringScheduleXTimeOfDay: ...
    @property
    def time_zone(self) -> global___OsConfigPatchDeploymentXRecurringScheduleXTimeZone: ...
    @property
    def weekly(self) -> global___OsConfigPatchDeploymentXRecurringScheduleXWeekly: ...
    def __init__(
        self,
        *,
        end_time: builtins.str = ...,
        last_execute_time: builtins.str = ...,
        next_execute_time: builtins.str = ...,
        start_time: builtins.str = ...,
        monthly: global___OsConfigPatchDeploymentXRecurringScheduleXMonthly | None = ...,
        time_of_day: global___OsConfigPatchDeploymentXRecurringScheduleXTimeOfDay | None = ...,
        time_zone: global___OsConfigPatchDeploymentXRecurringScheduleXTimeZone | None = ...,
        weekly: global___OsConfigPatchDeploymentXRecurringScheduleXWeekly | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["monthly", b"monthly", "time_of_day", b"time_of_day", "time_zone", b"time_zone", "weekly", b"weekly"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_time", b"end_time", "last_execute_time", b"last_execute_time", "monthly", b"monthly", "next_execute_time", b"next_execute_time", "start_time", b"start_time", "time_of_day", b"time_of_day", "time_zone", b"time_zone", "weekly", b"weekly"]) -> None: ...

global___OsConfigPatchDeploymentXRecurringSchedule = OsConfigPatchDeploymentXRecurringSchedule

@typing_extensions.final
class OsConfigPatchDeploymentXRolloutXDisruptionBudget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIXED_FIELD_NUMBER: builtins.int
    PERCENTAGE_FIELD_NUMBER: builtins.int
    fixed: builtins.float
    percentage: builtins.float
    def __init__(
        self,
        *,
        fixed: builtins.float = ...,
        percentage: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fixed", b"fixed", "percentage", b"percentage"]) -> None: ...

global___OsConfigPatchDeploymentXRolloutXDisruptionBudget = OsConfigPatchDeploymentXRolloutXDisruptionBudget

@typing_extensions.final
class OsConfigPatchDeploymentXRollout(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODE_FIELD_NUMBER: builtins.int
    DISRUPTION_BUDGET_FIELD_NUMBER: builtins.int
    mode: builtins.str
    @property
    def disruption_budget(self) -> global___OsConfigPatchDeploymentXRolloutXDisruptionBudget: ...
    def __init__(
        self,
        *,
        mode: builtins.str = ...,
        disruption_budget: global___OsConfigPatchDeploymentXRolloutXDisruptionBudget | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["disruption_budget", b"disruption_budget"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disruption_budget", b"disruption_budget", "mode", b"mode"]) -> None: ...

global___OsConfigPatchDeploymentXRollout = OsConfigPatchDeploymentXRollout

@typing_extensions.final
class OsConfigPatchDeploymentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___OsConfigPatchDeploymentXTimeouts = OsConfigPatchDeploymentXTimeouts

@typing_extensions.final
class OsConfigPatchDeployment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LAST_EXECUTE_TIME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PATCH_DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    INSTANCE_FILTER_FIELD_NUMBER: builtins.int
    ONE_TIME_SCHEDULE_FIELD_NUMBER: builtins.int
    PATCH_CONFIG_FIELD_NUMBER: builtins.int
    RECURRING_SCHEDULE_FIELD_NUMBER: builtins.int
    ROLLOUT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    description: builtins.str
    duration: builtins.str
    id: builtins.str
    last_execute_time: builtins.str
    name: builtins.str
    patch_deployment_id: builtins.str
    project: builtins.str
    update_time: builtins.str
    @property
    def instance_filter(self) -> global___OsConfigPatchDeploymentXInstanceFilter: ...
    @property
    def one_time_schedule(self) -> global___OsConfigPatchDeploymentXOneTimeSchedule: ...
    @property
    def patch_config(self) -> global___OsConfigPatchDeploymentXPatchConfig: ...
    @property
    def recurring_schedule(self) -> global___OsConfigPatchDeploymentXRecurringSchedule: ...
    @property
    def rollout(self) -> global___OsConfigPatchDeploymentXRollout: ...
    @property
    def timeouts(self) -> global___OsConfigPatchDeploymentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        duration: builtins.str = ...,
        id: builtins.str = ...,
        last_execute_time: builtins.str = ...,
        name: builtins.str = ...,
        patch_deployment_id: builtins.str = ...,
        project: builtins.str = ...,
        update_time: builtins.str = ...,
        instance_filter: global___OsConfigPatchDeploymentXInstanceFilter | None = ...,
        one_time_schedule: global___OsConfigPatchDeploymentXOneTimeSchedule | None = ...,
        patch_config: global___OsConfigPatchDeploymentXPatchConfig | None = ...,
        recurring_schedule: global___OsConfigPatchDeploymentXRecurringSchedule | None = ...,
        rollout: global___OsConfigPatchDeploymentXRollout | None = ...,
        timeouts: global___OsConfigPatchDeploymentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["instance_filter", b"instance_filter", "one_time_schedule", b"one_time_schedule", "patch_config", b"patch_config", "recurring_schedule", b"recurring_schedule", "resource_info", b"resource_info", "rollout", b"rollout", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "description", b"description", "duration", b"duration", "id", b"id", "instance_filter", b"instance_filter", "last_execute_time", b"last_execute_time", "name", b"name", "one_time_schedule", b"one_time_schedule", "patch_config", b"patch_config", "patch_deployment_id", b"patch_deployment_id", "project", b"project", "recurring_schedule", b"recurring_schedule", "resource_info", b"resource_info", "rollout", b"rollout", "timeouts", b"timeouts", "update_time", b"update_time"]) -> None: ...

global___OsConfigPatchDeployment = OsConfigPatchDeployment

@typing_extensions.final
class OsLoginSshPublicKeyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___OsLoginSshPublicKeyXTimeouts = OsLoginSshPublicKeyXTimeouts

@typing_extensions.final
class OsLoginSshPublicKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPIRATION_TIME_USEC_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    expiration_time_usec: builtins.str
    fingerprint: builtins.str
    id: builtins.str
    key: builtins.str
    project: builtins.str
    user: builtins.str
    @property
    def timeouts(self) -> global___OsLoginSshPublicKeyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        expiration_time_usec: builtins.str = ...,
        fingerprint: builtins.str = ...,
        id: builtins.str = ...,
        key: builtins.str = ...,
        project: builtins.str = ...,
        user: builtins.str = ...,
        timeouts: global___OsLoginSshPublicKeyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["expiration_time_usec", b"expiration_time_usec", "fingerprint", b"fingerprint", "id", b"id", "key", b"key", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts", "user", b"user"]) -> None: ...

global___OsLoginSshPublicKey = OsLoginSshPublicKey
